==> johnny-five-0.2.1.tgz: package/tpl/.readme.md <==
# Johnny 5, is in progress.

### [Firmata](https://github.com/jgautier/firmata) powered Arduino programming framework. "Node-isassemble Stephanie!"

## Demo Videos


### [Slider Controlled Panning Servo](http://jsfiddle.net/rwaldron/kZakv/show/light/)
### [Joystick Controlled Laser (pan/tilt) 1](http://jsfiddle.net/rwaldron/HPqms/show/light/)
### [Joystick Controlled Laser (pan/tilt) 2](http://jsfiddle.net/rwaldron/YHb7A/show/light/)
### [Joystick Controlled Claw](http://jsfiddle.net/rwaldron/6ZXFe/show/light/)
### [Robot Claw](http://jsfiddle.net/rwaldron/CFSZJ/show/light/)
### [Joystick, Motor & Led](http://jsfiddle.net/rwaldron/gADSz/show/light/)

## Getting Started

### Preparing the Arduino

- Download and open the [Arduino IDE](http://arduino.cc/hu/Main/Software)
- Plug in your Arduino or Arduino compatible microcontroller via USB
- From the IDE, select: File > Examples > Firmate > StandardFirmata
- Click the "Upload" button.

If the upload was successful, the board is now prepared and you can close the Arduino IDE.


### Getting Johnny Five:

#### Source Code:

``` bash
git clone git://github.com/rwldrn/johnny-five.git && cd johnny-five

npm install
```

#### npm package:

Install the module with:

```bash
npm install johnny-five
```


### A Simple Program


```javascript
var five = require("johnny-five"),
    board, led;

board = new five.Board({
  debug: true
});

board.on("ready", function() {

  led = new five.Led({
    pin: 13
  });

  led.strobe( 100 );
});
```

## Example Programs

<%= doclinks %>



## Contributing
All contributions must adhere to the the [Idiomatic.js Style Guide](https://github.com/rwldrn/idiomatic.js),
by maintaining the existing coding style. Add unit tests for any new or changed functionality. Lint and test your code using [grunt](https://github.com/cowboy/grunt).

## Release History
_(Nothing yet)_

## License
Copyright (c) 2012 Rick Waldron <waldron.rick@gmail.com>
Licensed under the MIT license.

==> johnny-five-0.2.3.tgz: package/tpl/.readme.md <==
<img src="https://github.com/rwldrn/johnny-five/raw/master/assets/johnny-five-js.png">

# Node-isassemble Johnny-Five


### [Firmata](https://github.com/jgautier/firmata) powered JavaScript Arduino programming framework.



## Many fragments. Some large, some small.


### [Slider Controlled Panning Servo](http://jsfiddle.net/rwaldron/kZakv/show/light/)
### [Joystick Controlled Laser (pan/tilt) 1](http://jsfiddle.net/rwaldron/HPqms/show/light/)
### [Joystick Controlled Laser (pan/tilt) 2](http://jsfiddle.net/rwaldron/YHb7A/show/light/)
### [Joystick Controlled Claw](http://jsfiddle.net/rwaldron/6ZXFe/show/light/)
### [Robot Claw](http://jsfiddle.net/rwaldron/CFSZJ/show/light/)
### [Joystick, Motor & Led](http://jsfiddle.net/rwaldron/gADSz/show/light/)



## Assemble Arduino

- Download and open the [Arduino IDE](http://arduino.cc/hu/Main/Software)
- Plug in your Arduino or Arduino compatible microcontroller via USB
- From the IDE, select: File > Examples > Firmate > StandardFirmata
- Click the "Upload" button.

If the upload was successful, the board is now prepared and you can close the Arduino IDE.


## Hey you, here's Johnny!

#### Source Code:

``` bash
git clone git://github.com/rwldrn/johnny-five.git && cd johnny-five

npm install
```

#### npm package:

Install the module with:

```bash
npm install johnny-five
```


## Johnny-Five is...


```javascript
var five = require("johnny-five"),
    board = new five.Board();

board.on("ready", function() {

  // Create an Led on pin 13 and strobe it on/off
  // Optionall set the speed; defaults to 100ms
  (new five.Led(13)).strobe();

});
```

#### [Watch it here!](http://jsfiddle.net/rwaldron/dtudh/show/light)


## More Input

<%= doclinks %>



## Contributing
All contributions must adhere to the the [Idiomatic.js Style Guide](https://github.com/rwldrn/idiomatic.js),
by maintaining the existing coding style. Add unit tests for any new or changed functionality. Lint and test your code using [grunt](https://github.com/cowboy/grunt).

## Release History
_(Nothing yet)_

## License
Copyright (c) 2012 Rick Waldron <waldron.rick@gmail.com>
Licensed under the MIT license.
